==> webreg-0.3.tar.gz: webreg-0.3/doregister.php <==
<?php
require("config.php");
?>

<p class="informative">Now registering your Jabber account with the transport. Please wait, this may take a minute or so</p>


<?php


/*
Plan of action!
1) Log into Jabber server
2) Send disco#items to the server's JID
3) Send disco#info to the JID of everything returned from the above request
4) Save to $gatewayjid When we find something that has category="gateway" and type="msn"
5) Send jabber:iq:register to $gatewayjid
6) Accept auth from $gatewayjid
7) Autoauthorise anything in the $gatewayjid domain that has roster-subsync flag
8) Respond with "I am not here" to any messages sent from MSN users in this time
9) Wait for 15 seconds
10) Disconnect from Jabber server

If there is a delay of more than 15 seconds between any of these steps, bail out & warn the user

*/



require("class.jabber.php");


// Globals
$tmp = explode("@", $_POST['jid']);
$user = $tmp[0];
$server = $tmp[1];
$jpassword = $_POST['jpassword'];
$lusername = $_POST['lusername'];
$lpassword = $_POST['lpassword'];
$nick = $_POST['nick'];
$gatewaytype = $_POST['gatewaytype'];
$SNAME = strtoupper($gatewaytype);
$gatewayjid = $gateways[$gatewaytype];
if($gatewayjid === "auto") {
	$gatewayjid = "";
}
$gatewayfound = FALSE;
$timeout = 25;
$registersuccess = FALSE;


Fprint("Connecting to your Jabber server...", "connecting");

// Connect to Jabber server
$JABBER = new Jabber;
$JABBER->server		= $server;
$JABBER->port		= 5222;
$JABBER->username	= $user;
$JABBER->password	= $jpassword;
$JABBER->resource	= "TransportRegister";
//$JABBER->enable_logging	= TRUE;
$JABBER->Connect() or die("Couldn't connect to your Jabber server. Please check your Jabber ID.");
$JABBER->SendAuth() or die("Couldn't authenticate with your Jabber server. Please check your Jabber ID and Jabber password.");
$JABBER->SendPresence(NULL, NULL, NULL, NULL, 1000);

Fprint("Connected!");

if(strlen($gatewayjid)) {
	// Register with the given JID
	doRegister($gatewayjid);
}
else {
	// Send disco request to look for one
	discoQueryItems($server);
}


// Loop
while($timeout > 0) {
	$JABBER->CruiseControl(1);
	$timeout--;
}
$JABBER->Disconnect();

if($registersuccess) {
	Fprint("You have been registered successfully with the $SNAME Gateway.");
}
else {
	if(!$gatewayjid) {
		Fprint("Could not find a $SNAME Transport on your server. Please contact your server administrator.", "error");
	}
	Fprint("There was an error registering you with the $SNAME Gateway. Please try again later.", "error");
}



// Actions

function Fprint($text, $cssclass="informative") {
	echo "\n<p class=\"$cssclass\">$text</p>\n";
	if($cssclass !== "uninformative") {
		for($i = 0; $i < 1000; $i++) {
			echo "\n<!-- blank space -->\n";
		}
	}
	flush();
	ob_flush();
}

function doRegister($jid) {
	global $JABBER;
	global $SNAME;
	global $registersuccess;
	global $lusername;
	global $lpassword;
	global $nick;

	Fprint("Attempting to register with $SNAME Gateway: $jid");

	$details = array();
	$details["username"] = $lusername;
	$details["password"] = $lpassword;
	if(strlen($nick) > 0) {
		$details["nick"] = $nick;
	}

	$ret = $JABBER->TransportRegistration($jid, $details);
	if($ret === 1 || $ret === 2) {
		$registersuccess = TRUE;
	}
	else {
		Fprint("There was an error registering with the transport. $ret", "error");
		resetTimeout(0);
	}
}

function discoQueryInfo($jid) {
	global $JABBER;
	$JABBER->txnid++;
	$packet =  "<iq type='get' to='$jid' id='{$JABBER->txnid}'>";
	$packet .= "<query xmlns='http://jabber.org/protocol/disco#info'/>";
	$packet .= "</iq>";
	$JABBER->SendPacket($packet);
}

function discoQueryItems($jid) {
	global $JABBER;
	$JABBER->txnid++;
	$packet =  "<iq type='get' to='$jid' id='{$JABBER->txnid}'>";
	$packet .= "<query xmlns='http://jabber.org/protocol/disco#items'/>";
	$packet .= "</iq>";
	$JABBER->SendPacket($packet);
}

function resetTimeout($val=25) {
	global $timeout;
	$timeout = $val;
}



// Handlers

function Handler_message_chat($packet) {
	Handler_message_normal($packet);
}

function Handler_message_normal($packet) {
	global $JABBER;
	$jid = $JABBER->StripJID($JABBER->GetInfoFromMessageFrom($packet));
	$response = "<message to='$jid'><body>Sorry, I did not receive that message. Please try again later.</body></message>";
	$JABBER->SendPacket($response);
	Fprint("Bouncing a message back to one of your contacts.", "warning");
}

function Handler_iq_http___jabber_org_protocol_disco_info($packet) {
	global $JABBER;
	global $SNAME;
	global $gatewaytype;
	global $gatewayjid;
	global $gatewayfound; // So that we don't register with two gateways by accident
	$jid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));

	if(!$packets['iq']['#']['query'][0]['#']['identity']) return;
	foreach($packet['iq']['#']['query'][0]['#']['identity'] as $i => $identity) {
		$category = $identity['@']['category'];
		$type = $identity['@']['type'];
		if($category === "gateway" && $type === $gatewaytype && $gatewayfound == FALSE) {
			Fprint("Found a $SNAME Transport");
			$gatewayjid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));
			$gatewayfound = TRUE;
			doRegister($gatewayjid);
			resetTimeout();
			return;
		}
	}
}

function Handler_iq_http___jabber_org_protocol_disco_items($packet) {
	global $JABBER;
	global $server;
	
	$jid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));
	if($jid !== $server) {
		return;
	}

	Fprint("Got list of available services. Searching for a gateway...");

	if(!$packet['iq']['#']['query'][0]['#']['item']) return;
	foreach($packet['iq']['#']['query'][0]['#']['item'] as $i => $item) {
		$qjid = $item['@']['jid'];
		discoQueryInfo($qjid);
	}
	resetTimeout();
}

function Handler_presence_subscribe($packet)
{
	global $JABBER;
	global $gatewayjid;

	$jid = $JABBER->StripJID($JABBER->GetInfoFromPresenceFrom($packet));

	if($jid === $gatewayjid) {
		$JABBER->SubscriptionAcceptRequest($jid);
		$JABBER->Subscribe($jid);
		resetTimeout();
		return;
	}
	
	// Check to see if it has roster-subsync flag and is from the $gatewayjid domain

	$domain = explode("@", $jid);
	if(count($domain) > 0) {
		$domain = $domain[1];
	}
	else {
		$domain = "";
	}

	if(!$packet['presence']['#']['x']) return;
	foreach($packet['presence']['#']['x'] as $i => $x) {
		$xmlns = $x['@']['xmlns'];
		if($xmlns === "http://jabber.org/protocol/roster-subsync" and $domain === $gatewayjid) {
			Fprint("Importing contact: $jid", "uninformative");
			$JABBER->SubscriptionAcceptRequest($jid);
			$JABBER->Subscribe($jid);
			resetTimeout();
		}
	}

}

function Handler_iq_jabber_iq_roster($packet) {

}


?>

==> webreg-0.4.tar.gz: webreg-0.4/doregister.php <==
<?php
require("config.php");
?>

<p class="informative">Now registering your Jabber account with the transport. Please wait, this may take a minute or so</p>


<?php


/*
Plan of action!
1) Log into Jabber server
2) Send disco#items to the server's JID
3) Send disco#info to the JID of everything returned from the above request
4) Save to $gatewayjid When we find something that has category="gateway" and type="msn"
5) Send jabber:iq:register to $gatewayjid
6) Accept auth from $gatewayjid
7) Autoauthorise anything in the $gatewayjid domain that has roster-subsync flag
8) Respond with "I am not here" to any messages sent from MSN users in this time
9) Wait for 15 seconds
10) Disconnect from Jabber server

If there is a delay of more than 15 seconds between any of these steps, bail out & warn the user

*/



require("class.jabber.php");


// Globals
$tmp = explode("@", $_POST['jid']);
$user = $tmp[0];
$server = $tmp[1];
$jpassword = $_POST['jpassword'];
$lusername = $_POST['lusername'];
$lpassword = $_POST['lpassword'];
$nick = $_POST['nick'];
$gatewaytype = $_POST['gatewaytype'];
$SNAME = strtoupper($gatewaytype);
$gatewayjid = $gateways[$gatewaytype];
if($gatewayjid === "auto") {
	$gatewayjid = "";
}
$gatewayfound = FALSE;
$timeout = 25;
$registersuccess = FALSE;


Fprint("Connecting to your Jabber server...", "connecting");

// Connect to Jabber server
$JABBER = new Jabber;
$JABBER->server		= $server;
$JABBER->port		= 5222;
$JABBER->username	= $user;
$JABBER->password	= $jpassword;
$JABBER->resource	= "TransportRegister";
//$JABBER->enable_logging	= TRUE;
$JABBER->Connect() or die("Couldn't connect to your Jabber server. Please check your Jabber ID.");
$JABBER->SendAuth() or die("Couldn't authenticate with your Jabber server. Please check your Jabber ID and Jabber password.");
$JABBER->SendPresence(NULL, NULL, NULL, NULL, 1000);

Fprint("Connected!");

if(strlen($gatewayjid)) {
	// Register with the given JID
	doRegister($gatewayjid);
}
else {
	// Send disco request to look for one
	discoQueryItems($server);
}


// Loop
while($timeout > 0) {
	$JABBER->CruiseControl(1);
	$timeout--;
}
$JABBER->Disconnect();

if($registersuccess) {
	Fprint("You have been registered successfully with the $SNAME Gateway.");
}
else {
	if(!$gatewayjid) {
		Fprint("Could not find a $SNAME Transport on your server. Please contact your server administrator.", "error");
	}
	Fprint("There was an error registering you with the $SNAME Gateway. Please try again later.", "error");
}



// Actions

function Fprint($text, $cssclass="informative") {
	echo "\n<p class=\"$cssclass\">$text</p>\n";
	if($cssclass !== "uninformative") {
		for($i = 0; $i < 1000; $i++) {
			echo "\n<!-- blank space -->\n";
		}
	}
	flush();
	ob_flush();
}

function doRegister($jid) {
	global $JABBER;
	global $SNAME;
	global $registersuccess;
	global $lusername;
	global $lpassword;
	global $nick;

	Fprint("Attempting to register with $SNAME Gateway: $jid");

	$details = array();
	$details["username"] = $lusername;
	$details["password"] = $lpassword;
	if(strlen($nick) > 0) {
		$details["nick"] = $nick;
	}

	$ret = $JABBER->TransportRegistration($jid, $details);
	if($ret === 1 || $ret === 2) {
		$registersuccess = TRUE;
	}
	else {
		Fprint("There was an error registering with the transport. $ret", "error");
		resetTimeout(0);
	}
}

function discoQueryInfo($jid) {
	global $JABBER;
	$JABBER->txnid++;
	$packet =  "<iq type='get' to='$jid' id='{$JABBER->txnid}'>";
	$packet .= "<query xmlns='http://jabber.org/protocol/disco#info'/>";
	$packet .= "</iq>";
	$JABBER->SendPacket($packet);
}

function discoQueryItems($jid) {
	global $JABBER;
	$JABBER->txnid++;
	$packet =  "<iq type='get' to='$jid' id='{$JABBER->txnid}'>";
	$packet .= "<query xmlns='http://jabber.org/protocol/disco#items'/>";
	$packet .= "</iq>";
	$JABBER->SendPacket($packet);
}

function resetTimeout($val=25) {
	global $timeout;
	$timeout = $val;
}



// Handlers

function Handler_message_chat($packet) {
	Handler_message_normal($packet);
}

function Handler_message_normal($packet) {
	global $JABBER;
	global $nobounce;

	$jid = $JABBER->StripJID($JABBER->GetInfoFromMessageFrom($packet));
	if(in_array($jid, $nobounce)) return; // Don't bounce this message

	$response = "<message to='$jid'><body>Sorry, I did not receive that message. Please try again later.</body></message>";
	$JABBER->SendPacket($response);
	Fprint("Bouncing a message back to one of your contacts.", "warning");
}

function Handler_iq_http___jabber_org_protocol_disco_info($packet) {
	global $JABBER;
	global $SNAME;
	global $gatewaytype;
	global $gatewayjid;
	global $gatewayfound; // So that we don't register with two gateways by accident
	$jid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));

	if(!$packet['iq']['#']['query'][0]['#']['identity']) return;
	foreach($packet['iq']['#']['query'][0]['#']['identity'] as $i => $identity) {
		$category = $identity['@']['category'];
		$type = $identity['@']['type'];
		if($category === "gateway" && $type === $gatewaytype && $gatewayfound == FALSE) {
			Fprint("Found a $SNAME Transport");
			$gatewayjid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));
			$gatewayfound = TRUE;
			doRegister($gatewayjid);
			resetTimeout();
			return;
		}
	}
}

function Handler_iq_http___jabber_org_protocol_disco_items($packet) {
	global $JABBER;
	global $server;
	
	$jid = $JABBER->StripJID($JABBER->GetInfoFromIqFrom($packet));
	if($jid !== $server) {
		return;
	}

	Fprint("Got list of available services. Searching for a gateway...");

	if(!$packet['iq']['#']['query'][0]['#']['item']) return;
	foreach($packet['iq']['#']['query'][0]['#']['item'] as $i => $item) {
		$qjid = $item['@']['jid'];
		discoQueryInfo($qjid);
	}
	resetTimeout();
}

function Handler_presence_subscribe($packet)
{
	global $JABBER;
	global $gatewayjid;

	$jid = $JABBER->StripJID($JABBER->GetInfoFromPresenceFrom($packet));

	if($jid === $gatewayjid) {
		$JABBER->SubscriptionAcceptRequest($jid);
		$JABBER->Subscribe($jid);
		resetTimeout();
		return;
	}
	
	// Check to see if it has roster-subsync flag and is from the $gatewayjid domain

	$domain = explode("@", $jid);
	if(count($domain) > 0) {
		$domain = $domain[1];
	}
	else {
		$domain = "";
	}

	if(!$packet['presence']['#']['x']) return;
	foreach($packet['presence']['#']['x'] as $i => $x) {
		$xmlns = $x['@']['xmlns'];
		if($xmlns === "http://jabber.org/protocol/roster-subsync" and $domain === $gatewayjid) {
			Fprint("Importing contact: $jid", "uninformative");
			$JABBER->SubscriptionAcceptRequest($jid);
			$JABBER->Subscribe($jid);
			resetTimeout();
		}
	}

}

function Handler_iq_jabber_iq_roster($packet) {

}


?>
